﻿Imports System.Net.Sockets
Imports System.Net
Imports System.Text
Imports System.Threading
Imports System.Text.RegularExpressions




Public Class frmMain
    Private udpClient As New UdpClient


    ''' <summary>
    ''' Form load event. The first procedure of the program.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub FrmMain_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        lblFreq.Text = frequencySlider.Value & " Hz"
        inpPort.Text = My.Settings.Port()
        inpAddress.Text = My.Settings.IP()
    End Sub





    ''' <summary>
    ''' cmdSendToServer will initiate a broadcast.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub cmdSendToServer_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdSendToServer.Click
        If fieldsAreValid() Then
            addLog("send Freq=" & frequencySlider.Value & " Hz")
            sendMessage()
        End If
    End Sub





    ''' <summary>
    ''' addLog will add a new line to the output log. It includes a timestamp, followed by a text.
    ''' </summary>
    ''' <param name="newLine">the text of the line to add (without timestamp)</param>
    ''' <remarks></remarks>
    Private Sub addLog(ByVal newLine As String)
        lstLog.Items.Add(Format(Now(), "dd/MM HH:mm") & "   " & newLine)
        lstLog.SelectedIndex = lstLog.Items.Count() - 1
    End Sub





    ''' <summary>
    ''' getPort returns the current port
    ''' </summary>
    ''' <returns>An Integer indicating the port which was typed into the inputbox.</returns>
    ''' <remarks></remarks>
    Private Function getPort() As Integer
        Dim port As Integer = 1000 'Use port 1000 in case of an error
        If Integer.TryParse(inpPort.Text, port) Then
            Return port
        End If
    End Function





    ''' <summary>
    ''' sendMessage will send a message to the given UDP address.
    ''' </summary>
    ''' <remarks></remarks>
    Private Sub sendMessage()
        Try
            Dim bytCommand As Byte() = New Byte() {}
            Dim pret As Integer
            Debug.Print("Connecting to UDP server : " & inpAddress.Text & " " & getPort())
            udpClient.Connect(inpAddress.Text, getPort())
            bytCommand = Encoding.UTF8.GetBytes("FREQ " & frequencySlider.Value)
            pret = udpClient.Send(bytCommand, bytCommand.Length)

        Catch ex As Exception
            Debug.Print("Error: " & ex.Message)
        End Try
    End Sub





    ''' <summary>
    ''' fieldsAreValid is called to determine if all of the values entered in the input boxes are valid.
    ''' </summary>
    ''' <returns>Returns a boolean to indicate the inputs are valid (True means: everything is valid)</returns>
    ''' <remarks></remarks>
    Private Function fieldsAreValid() As Boolean
        Dim response = True

        Dim r As New Regex("")

        r = New Regex("^\b(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\b$")
        If Not r.IsMatch(inpAddress.Text) Then
            ErrorProvider1.SetError(inpAddress, "The IP address is not valid. Select a valid one. For Example: 255.255.255.0")
            response = False
        Else
            ErrorProvider1.SetError(inpAddress, "")
        End If


        Dim iPort As Integer
        If Integer.TryParse(inpPort.Text, iPort) Then
            If iPort > 0 And iPort < 65535 Then
                ErrorProvider1.SetError(inpPort, "")
            Else
                ErrorProvider1.SetError(inpPort, "Select an UDP port between 1 and 65535. Default port is 2000.")
                response = False
            End If
        Else
            ErrorProvider1.SetError(inpPort, "Select an UDP port between 1 and 65535. Default port is 2000")
            response = False
        End If

        Return response
    End Function



    ''' <summary>
    ''' frequencySlider_Scroll is called when somesone slides the frequency slider control.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub frequencySlider_Scroll(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles frequencySlider.Scroll
        lblFreq.Text = frequencySlider.Value & " Hz"
    End Sub





    ''' <summary>
    ''' inpAddress_TextChanged is called when the contents of the textfield with the IP address is changed.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub inpAddress_TextChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles inpAddress.TextChanged
        My.Settings.IP = inpAddress.Text
    End Sub





    ''' <summary>
    ''' inpAddress_TextChanged is called when the contents of the textfield with the UDP port is changed.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub inpPort_TextChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles inpPort.TextChanged
        My.Settings.Port = inpPort.Text
    End Sub
End Class